Learn R Programming

espadon (version 1.11.3)

castlow.str: Cast of a character string

Description

The castlow.str function converts a word to lowercase, without accents and spaces.

Usage

castlow.str(st)

Value

Returns the ASCII//TRANSLIT transcription of the word st, without accents, spaces and in lowercase letters.

Arguments

st

character string

See Also

castup.str.

Examples

Run this code
castlow.str (st = c("Right eye", "Left_Lung", "Right-Lung"))

Run the code above in your browser using DataLab