castup.str: Cast of a character string

View source: R/castup_str.R

castup.strR Documentation

Cast of a character string

Description

The castup.str function converts a word to upper case, without accents and spaces.

Usage

castup.str(st)

Arguments

st

character string

Value

Returns the ASCII//TRANSLIT transcription of the word st, without accents, spaces and in capitals.

See Also

castlow.str.

Examples

castup.str (st = c("Right eye", "Left_Lung", "Right-Lung"))

espadon documentation built on May 8, 2026, 9:07 a.m.