- struct
"struct" class object. See espadon.class for
class definitions.
- roi.name
Vector of exact names of the RoI in the struct object.
By default roi.name = NULL. See Details.
- roi.sname
Vector of names or parts of names of the RoI in the struct object.
By default roi.sname = NULL. See Details.
- roi.idx
Vector of indices of the RoI that belong to the struct object.
By default roi.idx = NULL. See Details.
- roi.col
Color of the RoI. If roi.col = NULL (default),the RoI
colors are specified in the struct$roi.info.
- roi.print
Boolean vector indicating whether to display the pseudonym
of the RoI.
- roi.lwd
Line width of the RoI, by default at 1.
- roi.cex
Numeric character expansion factor of RoI name if
roi.print = TRUE, defaults to 1.
- display.ref
Pseudonym of frame of reference of the display.
- T.MAT
"t.mat" class object, created by load.patient.from.Rdcm or
load.T.MAT. If T.MAT = NULL, display.ref must be equal to NULL or to
struct$ref.pseudo.
- FoR.axis
Boolean or numeric, by default set to FALSE. If FoR.axis = TRUE,
the function displays 200 mm length director vectors of the frame of reference.
If FoR.axis is numeric, it represent the length in mm of the director vectors.
- FoR.col
Color of the frame of reference.