Learn R Programming

espadon (version 1.11.3)

display.DVH: Display of a DVH

Description

The display.DVH function displays the Dose Volume Histogram of a "dvh" class object. Y-units are cm^3ascii.

Usage

display.DVH(
  dvh,
  add = FALSE,
  xgrid = TRUE,
  ygrid = TRUE,
  MC.plot = FALSE,
  MC.col = grey.colors(4, rev = TRUE),
  ...
)

Value

Returns a plot of the cumulative histogram included in dvh, with its median, and the quantile areas (0%-100%), (2.5%-97.5%) and (25%-75%) of the dvh$vol variations, if they exist.

Arguments

dvh

"dvh" class object.

add

Boolean indicating whether to display the background image.

xgrid

Boolean indicating the display of the x grid.

ygrid

Boolean indicating the display of the y grid.

MC.plot

Boolean. If MC.plot = TRUE, then display.DVH displays, if they exist, the quantile zones (Prob = 0, .025, .25, .5, .75, .975, 1) of MC DVH variations.

MC.col

Character string, a valid palette with 4 colours corresponding to 100%, 95%, 50% and median of MC data.

...

Additional arguments xlab, ylab, xlim, ylim, main, type, col, lwd, lty and log managed by the plot function.

See Also

display.DVH.pc

Examples

Run this code
# DVH without MCMC
# loading of toy-patient objects (decrease dxyz and increase beam.nb for 
# better result)
step <- 5 
patient <- toy.load.patient (modality = c("rtdose", "rtstruct"), roi.name = "",
                             dxyz = rep (step, 3), beam.nb = 3)
H <- histo.from.roi (patient$rtdose[[1]], patient$rtstruct[[1]], roi.name = "ptv", 
                     breaks = seq (0, 60, by = 2))
DVH <- histo.DVH (H)
display.DVH (DVH)

if (FALSE) {
# loading of toy-patient objects
patient <- toy.load.patient (modality = c("rtdose", "rtstruct"), 
                             roi.name = "gizzard",
                             dxyz = c (2, 2, 2), beam.nb = 3)

# Calculation of the histogram
H <- histo.from.roi (patient$rtdose[[1]], patient$rtstruct[[1]], 
                     roi.name = "gizzard", 
                     breaks = seq (0, 60, by = 1), MC = 100)

# DVH
DVH <- histo.DVH (H)
display.DVH (DVH, MC.plot = TRUE, ylim = c (0, 40))
}

Run the code above in your browser using DataLab