Learn R Programming

espadon (version 1.11.3)

display.DVH.pc: Display of a cumulative DVH in percent of total volume

Description

The display.DVH.pc function displays the Dose Volume Histogram of "dvh" class object. Y-units are percents of total volume.

Usage

display.DVH.pc(
  dvh,
  add = FALSE,
  xgrid = TRUE,
  ygrid = TRUE,
  MC.plot = FALSE,
  MC.col = grey.colors(4, rev = TRUE),
  ...
)

Value

Returns a plot in percent of total volume of the cumulative histogram included in dvh, with its median, and the quantile areas (0%-100%), (2.5%-97.5%) and (25%-75%) of the dvh$pcv variations, if they exist.

Arguments

dvh

"dvh" class object. See espadon.class for class definitions.

add

Boolean indicating whether to display the background image.

xgrid

Boolean indicating the display of the x grid.

ygrid

Boolean indicating the display of the y grid.

MC.plot

Boolean. If MC.plot = TRUE, then display.DVH.pc displays, if they exist, the quantile zones (Prob = 0, .025, .25, .5, .75, .975, 1) of MC DVH variations.

MC.col

Character string, a valid palette with 4 colours corresponding to 100%, 95%, 50% and median of MC data.

...

Arguments xlab, ylab, xlim, ylim, main, type, col, lwd, lty and log managed by the plot function.

See Also

display.DVH

Examples

Run this code
# loading of toy-patient objects (decrease dxyz and increase beam.nb for 
# better result)
step <- 5
patient <- toy.load.patient (modality = c("rtdose", "rtstruct"), 
                             roi.name = "gizzard", dxyz = rep (step, 3), 
                             beam.nb = 3)

# Calculation of the histogram
H <- histo.from.roi (patient$rtdose[[1]], patient$rtstruct[[1]], 
                     roi.name = "gizzard", 
                     breaks = seq (0, 60, by = 1))

# DVH
DVH <- histo.DVH (H)
display.DVH.pc (DVH)

Run the code above in your browser using DataLab