Learn R Programming

espadon (version 1.11.3)

display.dV_dx: Display of the volume density of a histogram

Description

The display.dV_dx function displays the volume density of a "histo" class object. Y-units are cm^3.Gy^-1ascii.

Usage

display.dV_dx(
  histo,
  add = FALSE,
  xgrid = TRUE,
  ygrid = TRUE,
  MC.plot = FALSE,
  MC.col = grey.colors(4, rev = TRUE),
  ...
)

Value

Returns a plot of the differential histogram included in histo, with its median, and the quantile areas (0%-100%), (2.5%-97.5%) and (25%-75%) of the histo$dv_dx variations, if they exist.

Arguments

histo

"histo" class object. See espadon.class for class definitions.

add

Boolean indicating whether to display the background image.

xgrid

Boolean indicating the display of the x grid.

ygrid

Boolean indicating the display of the y grid.

MC.plot

Boolean. If MC.plot = TRUE, then display.dV_dx displays, if they exist, the quantile zones (Prob = 0, .025, .25, .5, .75, .975, 1) of variations in volume density.

MC.col

Character string, a valid palette with 4 colours corresponding to 100%, 95%, 50% and median of MC data.

...

Additional arguments xlab, ylab, xlim, ylim, main, type, col, lwd, lty and log managed by the plot function.

See Also

display.histo.

Examples

Run this code
# loading of toy-patient objects (decrease dxyz and increase beam.nb for 
# better result)
step <- 5
patient <- toy.load.patient (modality = c("rtdose", "rtstruct"),
                             roi.name = "gizzard", dxyz = rep (step, 3), 
                             beam.nb = 3)

# Calculation of the differential histogram
H <- histo.from.roi (patient$rtdose[[1]], patient$rtstruct[[1]], 
                     roi.name = "gizzard", breaks = seq (0, 60, by = 2))
display.dV_dx (H, lwd = 2, col = '#00ff00', ylim = c (0,10))

Run the code above in your browser using DataLab