fan.beam: Creation of pyramid fan object with constant angle step.
Description
The fan.beam function creates a "fan" class object
containing, among others, the coordinates of the unit director vectors of
the rays of rectangular pyramid fan. Rays are uniformly distributed by angle.