Learn R Programming

espadon (version 1.11.3)

get.roi.connection: List of inter-connections between RoI

Description

The get.roi.connection function describes the interconnections between Regions of Interest (RoI), from an imaging volume of "cluster" modality, created by struct.clustering.

Usage

get.roi.connection(vol)

Value

Returns the list of regions of interest (RoI), where each item in the list gives the inter-connections with other RoI.

Arguments

vol

"volume" class object of "cluster" modality, created by struct.clustering

See Also

struct.clustering

Examples

Run this code
# loading of toy-patient objects (decrease dxyz for better result)
step <- 5
patient <- toy.load.patient (modality = c ("mr", "rtstruct"),  
                             dxyz = rep (step, 3))
MR <- patient$mr[[1]]
S <- patient$rtstruct[[1]]
cluster.vol <- struct.clustering (MR, S, T.MAT = patient$T.MAT, verbose = FALSE)

get.roi.connection (cluster.vol)

Run the code above in your browser using DataLab