Returns a "dvh" class object. This is a list including:
$patient: set to histo$patient.
$patient.name: set to histo$patient.name.
$patient.bd: set to histo$patient.bd.
$patient.sex: set to histo$patient.sex.
$file.basename: set to "".
$file.dirname: set to "".
$object.name: set to "".
$object.alias: alias of the dvh object..
$frame.of.reference: set to histo$frame.of.reference.
$ref.pseudo : set to histo$ref.pseudo.
$modality : set to "dvh".
$description: description of the dvh object. By default,
set to histo$description.
$creation.date: set to Sys.Date.
$nb.MC: set to histo$nb.MC.
$breaks: vector breakpoints.
$mids: vector of cell centers.
$mids.unit: Character string, representing the unit of the abcissa
of the DVH. For instance, "Gy", when vol is a rtdose.
$vol: cumulative volume receiving at least the doses defined by $mids.
$pcv: percentage of the total volume receiving at least the doses defined by $mids.
$MC.vol: cumulative volume associated with histo$MC.dV_dx, if it exists.
$MC.pcv: percentage of the total volume associated with histo$MC.dV_dx, if it exists.
$MC.dxyz: set to histo$MC.dxyz, if it exists.