- vol
"volume" class object
- struct
"struct" class object.
- roi.name
Exact name of a RoI in struct object. By default
roi.name = NULL. See Details.
- roi.sname
Name or part of name of a RoI in struct object.
By default roi.sname = NULL. See Details.
- roi.idx
Value of the index of a RoI that belong to the struct
object. By default roi.idx = NULL. See Details.
- T.MAT
"t.mat" class object, created by load.patient.from.Rdcm,
load.patient.from.dicom or load.T.MAT. If
T.MAT = NULL, struct$ref.pseudo must be equal to
vol$ref.pseudo.
- breaks
Vector giving the breakpoints between histogram cells. If
breaks = NULL, the chosen breakpoints are those used by the
hist function by default. If breaks are specified,
outside values of vol$vol3D.data are not taken into account.
- MC
If different from NULL (default value), number of calculations
that will be performed, by Monte-Carlo, by randomly moving the chosen RoI
over a random distance, generated according to a normal distribution with
mean translation defined by offset and
standard deviation sd.
- sd
Vector representing the standard deviation of distances in the 3
directions x, y and z.
- offset
Vector representing the translation of the RoI in the 3
directions x, y and z.
- over.sampling.factor
Strictly positive integer, or a vector of 3 strictly
positive integers, default to 1. Defined to oversample grids of vol.
Oversampling can be very time consuming.
- alias
Character string, $alias of the created object
- description
Character string, describing the the created object. If
the description = NULL (default value), it will be set to
struct$roi.info$roi.pseudo[roi.idx]