obj.create: Espadon object creating

View source: R/obj_create.R

obj.createR Documentation

Espadon object creating

Description

The obj.create function creates an espadon object with the essential properties it must have.

Usage

obj.create(class = c("", "volume", "struct", "mesh"), alias = "")

Arguments

class

Character string, representing an espadon class from among "volume", "struct" or "mesh".

alias

Character string, $alias of the created object.

Value

Returns a espadon class object (see espadon.class for class definitions).

See Also

vol.create, struct.create.

Examples

# Creation of an espadon mesh of a cube
M <- obj.create(class = "mesh")
M$mesh <- Rvcg::vcgIsotropicRemeshing(Rvcg::vcgBox(), 0.5) 
M$nb.faces <- ncol(M$mesh$it)
rgl::wire3d(M$mesh)

espadon documentation built on May 8, 2026, 9:07 a.m.