Returns an toy object of "patient" class, containing the modalities
defined in modality. See espadon.class for class definitions.
Arguments
modality
String vector, whose elements are chosen among the modalities
"ct", "mr", "rtstruct" and "rtdose".
roi.name
String vector, whose elements are chosen among the regions of
interest (RoI) "eye", "optical nerve", "brain", "labyrinth processing unit",
"energy unit", "gizzard", "ghost container" and "exhaust valve". Note that the
RoI "couch", "patient" and "ptv" are still present.
dxyz
Vector of length 3, representing the x, y, z steps in mm, between
ct, mr and rtdose voxels.
beam.nb
Positive integer. Number of radiotherapy beams in rtdose modality.