Learn R Programming

espadon (version 1.11.3)

vol.in.new.ref: Change of frame of reference of a volume

Description

The vol.in.new.ref function allows you to change the frame of reference of a volume.

Usage

vol.in.new.ref(vol, new.ref.pseudo, T.MAT, alias = "", description = NULL)

Value

Returns "volume" class object in the new frame of reference new.ref.pseudo.

Arguments

vol

"volume" class object.

new.ref.pseudo

pseudonym of the frame of reference in which the volume should be located. This new.ref.pseudo must exist in the T.MAT list.

T.MAT

"t.mat" class object, created by load.patient.from.dicom, load.patient.from.Rdcm, load.T.MAT or ref.add.

alias

Character string, $alias of the created object.

description

Character string, describing the created object. If description = NULL (default value), it will be that of the vol volume.

See Also

struct.in.new.ref

Examples

Run this code
# loading of toy-patient objects (decrease dxyz for  better result)
patient <- toy.load.patient (modality = c("ct", "mr"), roi.name = "", 
                             dxyz = c (4, 4, 4))
CT <- patient$ct[[1]]
CT.in.new.ref <- vol.in.new.ref (CT, patient$mr[[1]]$ref.pseudo, patient$T.MAT)

Run the code above in your browser using DataLab