vol.median: Median filter on a volume

View source: R/vol_median.R

vol.medianR Documentation

Median filter on a volume

Description

The vol.median function applies a 26-connectivity median filter on all the voxels of a "volume" class object.

Usage

vol.median(vol, alias = "", description = NULL)

Arguments

vol

"volume" class object.

alias

Character string, $alias of the created object.

description

Character string, describing the created object. If description = NULL (default value), it will be set to paste (vol$object.alias, "median").

Value

Returns a "volume" class object (see espadon.class for class definitions), with the same grid and modality as vol, in which voxels are filtered by a 26-connectivity median filter.

Examples

# loading of toy-patient objects (decrease dxyz and increase beam.nb for 
# better result)
step <- 3
pat <- toy.load.patient(modality = c("ct"), dxyz = rep(step, 3))
CT.median <- vol.median(pat$ct[[1]])

display.plane(CT.median, view.type = "sagi", view.coord = 61, 
              interpolate = FALSE)

espadon documentation built on May 8, 2026, 9:07 a.m.