powered by
The castlow.str function converts a word to lowercase, without accents and spaces.
castlow.str
castlow.str(st)
Returns the ASCII//TRANSLIT transcription of the word st, without accents, spaces and in lowercase letters.
st
character string
castup.str.
castlow.str (st = c("Right eye", "Left_Lung", "Right-Lung"))
Run the code above in your browser using DataLab