Learn R Programming

espadon (version 1.11.3)

espadon-package: espadon: Easy Study of Patient DICOM Data in Oncology

Description

Exploitation, processing and 2D-3D visualization of DICOM-RT files (structures, dosimetry, imagery) for medical physics and clinical research, in a patient-oriented perspective.

espadon works in a native way (user friendly):

  • on images (CT, MR, PT) and fully manages changes of referential (REG)

  • on dosimetry (rt-dose)

  • on structures (rt-struct)

It is also able to use any DICOM format file, as long as the user knows where to look for the information. In addition to the simplified use of the above-mentioned formats, espadon contains many functions that allow the user to rework documents to produce new features that can be integrated into machine learning.

espadon integrates functionalities:

  • file loading, patient-centered information fusion

  • handling of 3D images

    • changes of referential

    • resampling, filtering

  • Contour manipulation, allowing the creation of new contours

    • fusion, intersection, inversion, erosion, dilation, opening, closing

    • segmentation based on the image

  • 2D representation

    • with application of masks

    • and transport of structures in the new reference frames

  • ... and 3D

    • production of mesh for the representation

    • CT, MR or RTDose slices, RTstruct contours in 3D -space

  • for measurements

    • calculation of histograms (1D, 2D), DVH (integrating Monte-Carlo to simulate organ movements)

    • measurement of surfaces, radii of curvature (on the mesh) and volumes

    • calculation of standard dosimetry indicators

    • calculation of Spatial similarity metrics

    • calculation of error metrics for comparison between 2 volumes (e.g. comparison of sCT and CT for chaue ROI)

  • export of your own objects to DICOM (CT, MR, RTDose, RTStruct)

In the calculation flow, various objects are created and accessible to the developer for his own use.

Arguments

Author

Maintainer: Cathy Fontbonne contact.espadon@lpccaen.in2p3.fr (LPC-CAEN, France)

Authors:

  • Jean-Marc Fontbonne (LPC-CAEN, France)

Other contributors:

  • Nathan Azemar (LPC-CAEN, France) [contributor]

Cathy & Jean-Marc Fontbonne

See Also