Learn R Programming

espadon (version 1.11.3)

pal.rainbow: Rainbow palette

Description

The pal.rainbow function produces a color palette adapted to dose repesentation.

Usage

pal.rainbow(n, alpha = seq(0.8, 0, length.out = n))

Value

Returns a color-labeled vector of size n.

Arguments

n

Integer, number of colors to be in the palette

alpha

Vector representing the opacity, in the range of 0 (transparent) to 1 (opaque). If alpha = NULL, all colors are opaque.

Examples

Run this code
pal <- pal.rainbow (255)

image (x = seq (0, 70, length.out = 255), y = 1,
       z = matrix (seq (0, 70, length.out = 255), ncol = 1),
       col = pal,
       main = "Rainbow colors")

Run the code above in your browser using DataLab