powered by
The pal.rainbow function produces a color palette adapted to dose repesentation.
pal.rainbow
pal.rainbow(n, alpha = seq(0.8, 0, length.out = n))
Returns a color-labeled vector of size n.
n
Integer, number of colors to be in the palette
Vector representing the opacity, in the range of 0 (transparent) to 1 (opaque). If alpha = NULL, all colors are opaque.
alpha = NULL
pal <- pal.rainbow (255) image (x = seq (0, 70, length.out = 255), y = 1, z = matrix (seq (0, 70, length.out = 255), ncol = 1), col = pal, main = "Rainbow colors")
Run the code above in your browser using DataLab